@@ -76,6 +76,7 @@ struct _GrlLuaFactorySourcePrivate {
   GrlMediaType resolve_type;
   GHashTable *config_keys;
   GrlConfig *configs;
+  GResource *public_resource;
 };
 
 #ifdef GOA_ENABLED
@@ -133,6 +134,9 @@ static const GList *grl_lua_factory_source_supported_keys (GrlSource *source);
 
 static const GList *grl_lua_factory_source_slow_keys(GrlSource *source);
 
+static void grl_lua_factory_source_cancel (GrlSource *source,
+                                           guint operation_id);
+
 static void grl_lua_factory_source_search (GrlSource *source,
                                            GrlSourceSearchSpec *ss);
 
@@ -442,7 +446,7 @@ grl_lua_factory_source_new (gchar       *lua_plugin_path,
   g_clear_pointer (&source_tags, g_strfreev);
   g_clear_object (&source_icon);
 
-  g_object_set_data_full (G_OBJECT (source), "resources", resource, (GDestroyNotify) g_resource_unref);
+  source->priv->public_resource = resource;
   resource = NULL;
 
   ret = lua_plugin_source_operations (L, source->priv->fn);
@@ -485,7 +489,10 @@ bail:
     g_list_free (source->priv->slow_keys);
   }
 
-  g_clear_pointer (&resource, g_resource_unref);
+  if (resource) {
+    g_resources_unregister (resource);
+    g_clear_pointer (&resource, g_resource_unref);
+  }
   g_free (source_id);
   lua_close (L);
   return NULL;
@@ -507,6 +514,7 @@ grl_lua_factory_source_class_init (GrlLuaFactorySourceClass *klass)
   source_class->query = grl_lua_factory_source_query;
   source_class->resolve = grl_lua_factory_source_resolve;
   source_class->may_resolve = grl_lua_factory_source_may_resolve;
+  source_class->cancel = grl_lua_factory_source_cancel;
 
   g_type_class_add_private (klass, sizeof (GrlLuaFactorySourcePrivate));
 }
@@ -526,6 +534,10 @@ grl_lua_factory_source_finalize (GObject *object)
 
   g_clear_object (&source->priv->configs);
   g_clear_pointer (&source->priv->config_keys, g_hash_table_unref);
+  if (source->priv->public_resource) {
+    g_resources_unregister (source->priv->public_resource);
+    g_clear_pointer (&source->priv->public_resource, g_resource_unref);
+  }
 
   g_list_free (source->priv->resolve_keys);
   g_list_free (source->priv->supported_keys);
@@ -1407,11 +1419,11 @@ lua_plugin_source_all_keys (lua_State *L,
         supported_media = GRL_SUPPORTED_MEDIA_IMAGE;
       else if (g_strcmp0 (key_name, "all") == 0)
         supported_media = GRL_SUPPORTED_MEDIA_ALL;
-
-      if (supported_media == GRL_SUPPORTED_MEDIA_NONE) {
+      else if (g_strcmp0 (key_name, "none") == 0)
+        supported_media = GRL_SUPPORTED_MEDIA_NONE;
+      else
         GRL_WARNING ("(%s) value '%s' is not supported on %s.type ",
                      source_id, key_name, LUA_SOURCE_RESOLVE_KEYS);
-      }
     } else {
       GRL_WARNING ("(%s) expecting string on %s.type but got instead %s", source_id,
                    LUA_SOURCE_RESOLVE_KEYS, lua_typename (L, lua_type (L, -1)));
@@ -1501,6 +1513,18 @@ grl_lua_factory_source_supported_operations (GrlSource *source)
   return caps;
 }
 
+static void
+grl_lua_factory_source_cancel (GrlSource *source,
+                               guint operation_id)
+{
+  GrlLuaFactorySource *lua_source = GRL_LUA_FACTORY_SOURCE (source);
+  lua_State *L = lua_source->priv->l_st;
+
+  GRL_DEBUG ("grl_lua_factory_source_cancel (%s) %u",
+             grl_source_get_id (source), operation_id);
+  grl_lua_operations_cancel_operation (L, operation_id);
+}
+
 static void
 grl_lua_factory_source_search (GrlSource *source,
                                GrlSourceSearchSpec *ss)
@@ -1518,6 +1542,7 @@ grl_lua_factory_source_search (GrlSource *source,
   os = g_slice_new0 (OperationSpec);
   os->source = ss->source;
   os->operation_id = ss->operation_id;
+  os->cancellable = g_cancellable_new ();
   os->cb.result = ss->callback;
   os->user_data = ss->user_data;
   os->string = g_strdup (text);
@@ -1554,6 +1579,7 @@ grl_lua_factory_source_browse (GrlSource *source,
   os = g_slice_new0 (OperationSpec);
   os->source = bs->source;
   os->operation_id = bs->operation_id;
+  os->cancellable = g_cancellable_new ();
   os->media = bs->container;
   os->cb.result = bs->callback;
   os->user_data = bs->user_data;
@@ -1591,6 +1617,7 @@ grl_lua_factory_source_query (GrlSource *source,
   os = g_slice_new0 (OperationSpec);
   os->source = qs->source;
   os->operation_id = qs->operation_id;
+  os->cancellable = g_cancellable_new ();
   os->cb.result = qs->callback;
   os->user_data = qs->user_data;
   os->string = g_strdup (query);
@@ -1624,6 +1651,7 @@ grl_lua_factory_source_resolve (GrlSource *source,
   os = g_slice_new0 (OperationSpec);
   os->source = rs->source;
   os->operation_id = rs->operation_id;
+  os->cancellable = g_cancellable_new ();
   os->cb.resolve = rs->callback;
   os->media = rs->media;
   os->user_data = rs->user_data;
