@@ -49,7 +49,7 @@ function grl_source_browse(media_id)
       local url = 'http://www.' .. item .. '.fr/player'
       table.insert(urls, url)
     end
-    grl.fetch(urls, "radiofrance_now_fetch_cb")
+    grl.fetch(urls, radiofrance_now_fetch_cb)
   end
 end
 
