@@ -41,8 +41,6 @@
 #define GRL_LOG_DOMAIN_DEFAULT metadata_store_log_domain
 GRL_LOG_DOMAIN_STATIC(metadata_store_log_domain);
 
-#define PLUGIN_ID   METADATA_STORE_PLUGIN_ID
-
 #define SOURCE_ID   "grl-metadata-store"
 #define SOURCE_NAME _("Metadata Store")
 #define SOURCE_DESC _("A plugin for storing extra metadata information")
@@ -120,7 +118,7 @@ enum {
   MEDIA_AUDIO,
   MEDIA_VIDEO,
   MEDIA_IMAGE,
-  MEDIA_BOX
+  MEDIA_CONTAINER
 };
 
 static GrlMetadataStoreSource *grl_metadata_store_source_new (void);
@@ -174,9 +172,18 @@ grl_metadata_store_source_plugin_init (GrlRegistry *registry,
   return TRUE;
 }
 
-GRL_PLUGIN_REGISTER (grl_metadata_store_source_plugin_init,
-                     NULL,
-                     PLUGIN_ID);
+GRL_PLUGIN_DEFINE (GRL_MAJOR,
+                   GRL_MINOR,
+                   METADATA_STORE_PLUGIN_ID,
+                   "Metadata Store",
+                   "A plugin for storing extra metadata information",
+                   "Igalia S.L.",
+                   VERSION,
+                   "LGPL",
+                   "http://www.igalia.com",
+                   grl_metadata_store_source_plugin_init,
+                   NULL,
+                   NULL);
 
 /* ================== GrlMetadataStore GObject ================ */
 
@@ -248,8 +255,7 @@ grl_metadata_store_source_init (GrlMetadataStoreSource *source)
   if (r) {
     if (sql_error) {
       GRL_WARNING ("Failed to create database tables: %s", sql_error);
-      sqlite3_free (sql_error);
-      sql_error = NULL;
+      g_clear_pointer (&sql_error, sqlite3_free);
     } else {
       GRL_WARNING ("Failed to create database tables.");
     }
@@ -316,8 +322,16 @@ fill_metadata_from_stmt (GrlMedia *media, GList *keys, sqlite3_stmt *stmt)
       rating = sqlite3_column_double (stmt, STORE_RATING);
       grl_media_set_rating (media, rating, 5.00);
     } else if (key == GRL_METADATA_KEY_LAST_PLAYED) {
+      GDateTime *date;
       last_played = (gchar *) sqlite3_column_text (stmt, STORE_LAST_PLAYED);
-      grl_media_set_last_played (media, last_played);
+      date = grl_date_time_from_iso8601 (last_played);
+      if (date) {
+        grl_media_set_last_played (media, date);
+        g_date_time_unref (date);
+      } else {
+        GRL_WARNING ("Unable to set 'last-played', as '%s' date is invalid",
+                     last_played);
+      }
     } else if (key == GRL_METADATA_KEY_LAST_POSITION) {
       last_position = sqlite3_column_int (stmt, STORE_LAST_POSITION);
       grl_media_set_last_position (media, last_position);
@@ -370,17 +384,17 @@ get_column_name_from_key_id (GrlKeyID key_id)
 static int
 get_media_type (GrlMedia *media)
 {
-  if (GRL_IS_MEDIA_AUDIO (media)) {
+  if (grl_media_is_audio (media)) {
     return MEDIA_AUDIO;
   }
-  if (GRL_IS_MEDIA_VIDEO (media)) {
+  if (grl_media_is_video (media)) {
     return MEDIA_VIDEO;
   }
-  if (GRL_IS_MEDIA_IMAGE (media)) {
+  if (grl_media_is_image (media)) {
     return MEDIA_IMAGE;
   }
-  if (GRL_IS_MEDIA_BOX (media)) {
-    return MEDIA_BOX;
+  if (grl_media_is_container (media)) {
+    return MEDIA_CONTAINER;
   }
 
   return MEDIA;
@@ -396,7 +410,6 @@ bind_and_exec (sqlite3 *db,
 	       GrlMedia *media)
 {
   gint r;
-  const gchar *char_value;
   gint int_value;
   double double_value;
   GList *iter_names, *iter_keys;
@@ -434,8 +447,14 @@ bind_and_exec (sqlite3 *db,
 	int_value = grl_media_get_last_position (media);
 	sqlite3_bind_int (stmt, count, int_value);
       } else if (key == GRL_METADATA_KEY_LAST_PLAYED) {
-	char_value = grl_media_get_last_played (media);
-	sqlite3_bind_text (stmt, count, char_value, -1, SQLITE_STATIC);
+	GDateTime *date;
+	char *date_str;
+	date = grl_media_get_last_played (media);
+	if (date) {
+	  date_str = g_date_time_format (date, "%F %T");
+	  sqlite3_bind_text (stmt, count, date_str, -1, SQLITE_STATIC);
+	  g_free (date_str);
+	}
       } else if (key == GRL_METADATA_KEY_FAVOURITE) {
         int_value = (gint) grl_media_get_favourite (media);
         sqlite3_bind_int (stmt, count, int_value);
@@ -638,8 +657,8 @@ create_media (sqlite3_stmt * stmt, GList *keys)
   case MEDIA_IMAGE:
     media = grl_media_image_new ();
     break;
-  case MEDIA_BOX:
-    media = grl_media_box_new ();
+  case MEDIA_CONTAINER:
+    media = grl_media_container_new ();
     break;
   default:
     media = grl_media_new ();
@@ -721,12 +740,12 @@ grl_metadata_store_source_may_resolve (GrlSource *source,
 
 
   if (media) {
-    if (!(GRL_IS_MEDIA_VIDEO (media) ||
-          GRL_IS_MEDIA_AUDIO (media) ||
+    if (!(grl_media_is_video (media) ||
+          grl_media_is_audio (media) ||
           key_id == GRL_METADATA_KEY_FAVOURITE))
       /* the keys we handle for now only make sense for audio and video,
          with exception of the 'favourite' key, valid as well for pictures
-         and boxes */
+         and containers */
       return FALSE;
 
     if (grl_data_has_key (GRL_DATA (media), GRL_METADATA_KEY_ID))
@@ -817,9 +836,7 @@ grl_metadata_store_source_store_metadata (GrlSource *source,
 
   sms->callback (sms->source, sms->media, failed_keys, sms->user_data, error);
 
-  if (error) {
-    g_error_free (error);
-  }
+  g_clear_error (&error);
   g_list_free (failed_keys);
 }
 
