@@ -40,8 +40,6 @@ GRL_LOG_DOMAIN_STATIC(optical_media_log_domain);
 
 /* --- Plugin information --- */
 
-#define PLUGIN_ID   OPTICAL_MEDIA_PLUGIN_ID
-
 #define SOURCE_ID   "grl-optical-media"
 #define SOURCE_NAME _("Optical Media")
 #define SOURCE_DESC _("A source for browsing optical media")
@@ -126,9 +124,18 @@ grl_optical_media_plugin_init (GrlRegistry *registry,
   return TRUE;
 }
 
-GRL_PLUGIN_REGISTER (grl_optical_media_plugin_init,
-                     NULL,
-                     PLUGIN_ID);
+GRL_PLUGIN_DEFINE (GRL_MAJOR,
+                   GRL_MINOR,
+                   OPTICAL_MEDIA_PLUGIN_ID,
+                   "Optical Media",
+                   "A plugin for browsing optical media",
+                   "GNOME",
+                   VERSION,
+                   "LGPL",
+                   "http://www.gnome.org",
+                   grl_optical_media_plugin_init,
+                   NULL,
+                   NULL);
 
 /* ================== OpticalMedia GObject ================ */
 
@@ -310,7 +317,7 @@ ignore_drive (GDrive *drive)
   }
   g_clear_object (&icon);
 
-  return TRUE;
+  return FALSE;
 }
 
 static gboolean
@@ -377,6 +384,8 @@ create_media_from_mount (GMount *mount)
 
   /* Is it an audio CD or a blank media */
   if (ignore_mount (mount)) {
+    GRL_DEBUG ("%s: Ignoring mount %s", __FUNCTION__,
+               g_mount_get_name (mount));
     g_object_unref (mount);
     return NULL;
   }
@@ -396,6 +405,9 @@ create_media_from_mount (GMount *mount)
   media_set_metadata (mount, media);
   grl_media_set_mime (media, "x-special/device-block");
 
+  GRL_DEBUG ("%s: Adding mount %s (id: %s)", __FUNCTION__,
+             g_mount_get_name (mount), grl_media_get_id (media));
+
   return media;
 }
 
