@@ -88,8 +88,6 @@ GRL_LOG_DOMAIN_STATIC(raitv_log_domain);
 
 /* --- Plugin information --- */
 
-#define PLUGIN_ID   RAITV_PLUGIN_ID
-
 #define SOURCE_ID   "grl-raitv"
 #define SOURCE_NAME "Rai.tv"
 #define SOURCE_DESC _("A source for browsing and searching Rai.tv videos")
@@ -248,10 +246,18 @@ grl_raitv_plugin_init (GrlRegistry *registry,
   return TRUE;
 }
 
-GRL_PLUGIN_REGISTER (grl_raitv_plugin_init,
-                     NULL,
-                     PLUGIN_ID);
-
+GRL_PLUGIN_DEFINE (GRL_MAJOR,
+                   GRL_MINOR,
+                   RAITV_PLUGIN_ID,
+                   "Rai.tv",
+                   "A plugin for searching multimedia content using Rai.tv",
+                   "Marco Piazza",
+                   VERSION,
+                   "LGPL",
+                   "https://wiki.gnome.org/Projects/Grilo",
+                   grl_raitv_plugin_init,
+                   NULL,
+                   NULL);
 
 /* ================== Rai.tv GObject ================ */
 
@@ -261,6 +267,12 @@ grl_raitv_source_new (void)
   GIcon *icon;
   GFile *file;
   GrlRaitvSource *source;
+  const char *tags[] = {
+    "country:it",
+    "tv",
+    "net:internet",
+    NULL
+  };
 
   file = g_file_new_for_uri ("resource:///org/gnome/grilo/plugins/raitv/channel-rai.svg");
   icon = g_file_icon_new (file);
@@ -269,8 +281,9 @@ grl_raitv_source_new (void)
                          "source-id", SOURCE_ID,
                          "source-name", SOURCE_NAME,
                          "source-desc", SOURCE_DESC,
-                         "supported-media", GRL_MEDIA_TYPE_VIDEO,
+                         "supported-media", GRL_SUPPORTED_MEDIA_VIDEO,
                          "source-icon", icon,
+                         "source-tags", tags,
                          NULL);
   g_object_unref (icon);
 
@@ -999,7 +1012,7 @@ produce_container_from_directory (GrlMedia *media,
   gchar* mediaid=NULL;
 
   if (!media) {
-    content = grl_media_box_new ();
+    content = grl_media_container_new ();
   } else {
     content = media;
   }
@@ -1254,7 +1267,7 @@ grl_raitv_source_resolve (GrlSource *source,
 
   GRL_DEBUG ("Starting resolve source: url=%s",grl_media_get_url (rs->media));
 
-  if (!GRL_IS_MEDIA_VIDEO (rs->media) && !GRL_IS_MEDIA_BOX (rs->media)) {
+  if (!grl_media_is_video (rs->media) && !grl_media_is_container (rs->media)) {
     rs->callback (rs->source, rs->operation_id, rs->media, rs->user_data, NULL);
     return;
   }
