@@ -204,11 +204,21 @@ grl_tracker_setup_key_mappings (void)
                       "nmm:albumTitle(nmm:musicAlbum(?urn))",
                       "audio");
 
+  insert_key_mapping (GRL_METADATA_KEY_ALBUM_DISC_NUMBER,
+                      NULL,
+                      "nmm:setNumber(nmm:musicAlbumDisc(?urn))",
+                      "audio");
+
   insert_key_mapping (GRL_METADATA_KEY_ARTIST,
                       NULL,
                       "nmm:artistName(nmm:performer(?urn))",
                       "audio");
 
+  insert_key_mapping (GRL_METADATA_KEY_ALBUM_ARTIST,
+                      NULL,
+                      "nmm:artistName(nmm:albumArtist(nmm:musicAlbum(?urn)))",
+                      "audio");
+
   insert_key_mapping (GRL_METADATA_KEY_AUTHOR,
                       NULL,
                       "nmm:artistName(nmm:performer(?urn))",
@@ -224,6 +234,11 @@ grl_tracker_setup_key_mappings (void)
                       "nfo:entryCounter(?urn)",
                       "directory");
 
+  insert_key_mapping (GRL_METADATA_KEY_COMPOSER,
+                      NULL,
+                      "nmm:artistName(nmm:composer(?urn))",
+                      "audio");
+
   insert_key_mapping (GRL_METADATA_KEY_SIZE,
                       NULL,
                       "nfo:fileSize(?urn)",
