@@ -275,6 +275,7 @@ grl_tracker_plugin_register_keys (GrlRegistry *registry,
                                                            NULL,
                                                            G_PARAM_STATIC_STRINGS |
                                                            G_PARAM_READWRITE),
+                                      GRL_METADATA_KEY_INVALID,
                                       NULL);
   grl_registry_register_metadata_key (grl_registry_get_default (),
                                       g_param_spec_string ("gibest-hash",
@@ -283,6 +284,7 @@ grl_tracker_plugin_register_keys (GrlRegistry *registry,
                                                            NULL,
                                                            G_PARAM_STATIC_STRINGS |
                                                            G_PARAM_READWRITE),
+                                      GRL_METADATA_KEY_INVALID,
                                       NULL);
   grl_registry_register_metadata_key (grl_registry_get_default (),
                                       g_param_spec_string ("tracker-urn",
@@ -291,10 +293,19 @@ grl_tracker_plugin_register_keys (GrlRegistry *registry,
                                                            NULL,
                                                            G_PARAM_STATIC_STRINGS |
                                                            G_PARAM_READWRITE),
+                                      GRL_METADATA_KEY_INVALID,
                                       NULL);
 }
 
-GRL_PLUGIN_REGISTER_FULL (grl_tracker_plugin_init,
-                          grl_tracker_plugin_deinit,
-                          grl_tracker_plugin_register_keys,
-                          GRL_TRACKER_PLUGIN_ID);
+GRL_PLUGIN_DEFINE (GRL_MAJOR,
+                   GRL_MINOR,
+                   GRL_TRACKER_PLUGIN_ID,
+                   "Tracker",
+                   "A plugin for searching multimedia content using Tracker",
+                   "Igalia S.L.",
+                   VERSION,
+                   "LGPL",
+                   "http://www.igalia.com",
+                   grl_tracker_plugin_init,
+                   grl_tracker_plugin_deinit,
+                   grl_tracker_plugin_register_keys);
